#pragma implementation
#include <stdlib.h>
#include "modapi.h"
#include "internal.h"


PUBLIC M_DIALOG_INTERNAL::M_DIALOG_INTERNAL()
{
	combo = NULL;
	fmany = NULL;
	fenum = NULL;
	list = NULL;
	clist = NULL;
	btext = NULL;
	bicon = NULL;
}

static void internal_delete (M_DIALOG_OBJECT *first)
{
	while (first != NULL){
		M_DIALOG_OBJECT *next = first->next;
		delete first;
		first = next;
	}
}

PUBLIC M_DIALOG_INTERNAL::~M_DIALOG_INTERNAL()
{
	internal_delete (combo);
	internal_delete (fmany);
	internal_delete (fenum);
	internal_delete (list);
	internal_delete (clist);
	internal_delete (btext);
	internal_delete (bicon);
}

